@@ -5,7 +5,7 @@ use warnings;
 
 use parent qw(Tickit::Widget);
 
-our $VERSION = '0.213';
+our $VERSION = '0.214';
 
 =head1 NAME
 
@@ -13,7 +13,7 @@ Tickit::Widget::Table - table widget with support for scrolling/paging
 
 =head1 VERSION
 
-version 0.213
+version 0.214
 
 =head1 SYNOPSIS
 
@@ -524,7 +524,7 @@ sub body_rect {
 	my $self = shift;
 	$self->{body_rect} ||= Tickit::Rect->new(
 		top   => $self->header_lines,
-		bottom => $self->window->lines - 1,
+		lines => $self->window->lines - $self->header_lines,
 		left  => 0,
 		cols  => $self->window->cols - 1
 	);
@@ -651,6 +651,11 @@ sub idx_from_row_cache {
 	return $row + $self->row_offset - $self->body_lines;
 }
 
+sub column_width {
+	my ($self, $idx) = @_;
+	$self->{columns}[$idx]{value};
+}
+
 =head2 highlight_row
 
 Returns the index of the currently-highlighted row.
